import React, { useEffect, useState } from 'react';
import { FlatList, View, Text } from 'react-native';
import { Image } from 'expo-image';

import { Header, Loading, PageWrapper } from '../../../../components';
import {
  getStatistic,
  StatisticType,
  Type2,
  Type1,
  Type3
} from '../../../../database/statisticsService';
import { API_HOST } from '../../../../constants';
import { Colors } from '../../../../theme';
import { getFontSize } from '../../../../utils';

const StatisticsListScreen = ({ route }) => {
  const title = route.params.title;
  const url1 = route.params.url1;

  const [isLoading, setIsLoading] = useState(true);
  const [statistic, setStatistic] = useState<StatisticType | null>(null);

  useEffect(() => {
    const data = getStatistic(url1);

    if (!data) return;

    setStatistic(JSON.parse(data as unknown as string) as unknown as StatisticType);
    setIsLoading(false);
  }, []);

  if (isLoading) return <Loading />;
  if (!statistic) return null;

  console.log(statistic);

  const renderItem = ({ item, index }: { index: number; item: Type1 | Type2 | Type3 }) => {
    if ('region_id' in item) {
      return (
        <View
          style={{
            display: 'flex',
            alignItems: 'center',
            flexDirection: 'row',
            flex: 1,
            gap: 8
          }}
        >
          <Text style={{ color: Colors.DARK_BLUE, fontSize: getFontSize(18), fontWeight: '700' }}>
            {index + 1}
          </Text>
          <Image
            style={{ width: 36, height: 36, borderRadius: 18 }}
            source={{ uri: API_HOST + '/img/flags_new/' + (item.flag ?? item.region_flag) }}
          />
          <View
            style={{
              flex: 1,
              display: 'flex',
              flexDirection: 'row',
              justifyContent: 'space-between',
              alignItems: 'center'
            }}
          >
            <Text style={{ width: '75%', color: Colors.DARK_BLUE, fontWeight: '700' }}>
              {item.region_name ?? item.region}
            </Text>
            <Text style={{ color: Colors.DARK_BLUE, fontWeight: '700' }}>{item.cnt}</Text>
          </View>
        </View>
      );
    } else if ('mega_id' in item) {
      return (
        <View
          style={{
            display: 'flex',
            alignItems: 'center',
            flexDirection: 'row',
            flex: 1,
            gap: 8
          }}
        >
          <Text style={{ color: Colors.DARK_BLUE, fontSize: getFontSize(18), fontWeight: '700' }}>
            {index + 1}
          </Text>
          <Image
            style={{ width: 36, height: 36, borderRadius: 18 }}
            source={{ uri: API_HOST + '/img/flags_new/' + (item.dare_flag ?? item.flag) }}
          />
          <View
            style={{
              flex: 1,
              display: 'flex',
              flexDirection: 'row',
              justifyContent: 'space-between',
              alignItems: 'center'
            }}
          >
            <Text style={{ width: '75%', color: Colors.DARK_BLUE, fontWeight: '700' }}>
              {item.dare_name ?? item.country}
            </Text>
            <Text style={{ color: Colors.DARK_BLUE, fontWeight: '700' }}>{item.cnt}</Text>
          </View>
        </View>
      );
    } else if ('user' in item) {
      return (
        <View style={{ flexDirection: 'row', justifyContent: 'space-between' }}>
          <Text>
            {item.first_name} {item.last_name}
          </Text>
        </View>
      );
    } else {
      return (
        <View
          style={{
            display: 'flex',
            alignItems: 'center',
            flexDirection: 'row',
            flex: 1,
            gap: 8
          }}
        >
          <Text style={{ color: Colors.DARK_BLUE, fontSize: getFontSize(18), fontWeight: '700' }}>
            {index + 1}
          </Text>
          <Image
            style={{ width: 36, height: 36, borderRadius: 18 }}
            source={{ uri: API_HOST + '/img/flags_new/' + item.flag }}
          />
          <View
            style={{
              flex: 1,
              display: 'flex',
              flexDirection: 'row',
              justifyContent: 'space-between',
              alignItems: 'center'
            }}
          >
            <Text style={{ width: '75%', color: Colors.DARK_BLUE, fontWeight: '700' }}>
              {item.country_name ?? item.nation ?? item.item_name}
            </Text>
            <Text style={{ color: Colors.DARK_BLUE, fontWeight: '700' }}>
              {item.cnt ?? item.score}
            </Text>
          </View>
        </View>
      );
    }
  };

  return (
    <PageWrapper>
      <Header label={title} />
      <FlatList
        contentContainerStyle={{ gap: 10 }}
        horizontal={false}
        data={statistic.ranking}
        renderItem={renderItem}
        showsVerticalScrollIndicator={false}
      />
    </PageWrapper>
  );
};

export default StatisticsListScreen;
